@@ -20,7 +20,10 @@ EEE
 set -eu
 (
 cd `dirname $0`
-sh ./prebuild.sh		#updが展開済みソースが必要だから。
 sh ./extract.sh
-# sh ./upd.sh
+sh ./prebuild.sh
+
+mv ../src/tests.code ../seed/_tests/tests.c ||:
+
+sh ./upd.sh
 )
