@@ -32,7 +32,7 @@ done;[ "$Rc" = : ]&&Rc=$Cm;shift $((OPTIND-1));$Re"$C_$O$Rc";exit   #END GPL3+*/
 title=ureg section=3 repnl=\040
 @name	ureg
 @_brief	portable BRE/ERE regex api
-@synopsis
+@_syno
  #include "ureg.h"
  
  //main func 
@@ -65,7 +65,6 @@ title=ureg section=3 repnl=\040
 @tl;dr
 	@(code)@
 	#include "ureg.h"
-	
 	int main() {
 		  ureg_t res = ureg_easy("a[bc]", "123abc");	//dfl:ERE
 		  printf("%.*s \n", res.sz, res.p);	// == "ab"
@@ -87,7 +86,7 @@ title=ureg section=3 repnl=\040
 	printf("%.*s", res.szbk[0], res.pbk[0]);	//>> "ab"
 	
 	//complex
-	ureg_t* obj = ureg_new("a(b|c)");	//rtn NULL: err
+	ureg_t* obj = ureg_new("a(b|c)");	//rtn NULL if err
 	const char* s = "123abc";
 	int rc = ureg_search(obj, s);	//rc== hit:>=0 nohit/err:<0
 	  //rc=3, obj->p=s+3(rc), obj->sz=2 
@@ -105,6 +104,7 @@ title=ureg section=3 repnl=\040
 	setlocale(LC_CTYPE, "C");	// reset
 	rc = ureg_search(obj, s);
 	ureg_free(obj);
+	//--regex end
 	
 	//ureg_iconv(): not regex. conv encode UTF-8, EBCDIC etc
 	const char* s0 = "hwd";  //"hwd"=="\150\167\144" in C charset
@@ -123,7 +123,7 @@ title=ureg section=3 repnl=\040
   //~$ cc src.c libureg.a
 	@()@
 
-@description
+@_desc
 	ureg uses posix-ERE with the following expantion in default.
 	some items are compromised for reasons --
 	@(pre)@
@@ -138,25 +138,25 @@ title=ureg section=3 repnl=\040
     --
 
 	@(raw).SS easy mode@()--
-	'	'ureg_t ureg_easy(r, s [, rlen, slen, syn]); --
+	`	`ureg_t res = ureg_easy(r, s [, rlen, slen, syn]); --
 	--
 	ureg_easy() uses for oneshot search. use '-1' if rlen/slen/syn isnt set.
 	search result is set to rtn. if nohit, set res.p==NULL, res.sz<0. --
-	'  'res = ureg_easy("a[bc]", "123abc");  //hit, res.p="..."+3, res.sz=2 --
-	'  'res = ureg_easy("a[bc]", "123abc", -1,-1,-1);  //same --
+	`	`res = ureg_easy("a[bc]", "123abc");  //hit, res.p="..."+3, res.sz=2 --
+	`	`res = ureg_easy("a[bc]", "123abc", -1,-1,-1);  //same --
 	--
-	'_param'
+	`_param`
 	@(pre)
 	r     : regex str
 	s     : search target string/binary
 	[rlen]: r size. use strlen(r) if set -1/noset
 	[slen]: s size
-	[syn] : change regex syntax. see below 'complex mode'
+	[syn] : change regex syntax. see below 'complex mode'. (dfl:ERE)
 	@()--
 
-	'_return'
+	`_return`
 	@(pre)
-    res.p : matched ptr. res.p[0]==@'a@' in above sample. "123(a)bc"
+    res.p : matched ptr. res.p[0]=='a' in above sample. "123(a)bc"
     res.sz: match string byte size
     others: see below (complex mode)
     @()--
@@ -169,12 +169,12 @@ title=ureg section=3 repnl=\040
 	sample:
 		@(pre)
 	#include "ureg.h"
-	int main(int argc, char** argv){
+	int main(){
 		ureg_t res = ureg_easy("a[bc]", "123abc");
-		printf("%.*s \n" res.sz, res.p);	//>> disp "ab"
+		printf("%.*s \n", res.sz, res.p);	//>> disp "ab"
 		return 0;	//no memleak
 	}
-	// ~$ gcc src.c libureg.a
+	// ~$ cc src.c libureg.a
 		@()--
 	@(raw).SS complex mode@()--
 	divided to 3 parts, compile >> search >> free	--
@@ -186,20 +186,20 @@ title=ureg section=3 repnl=\040
 	int syn = ureg_ere_syn();
 	int syn = ureg_bre_syn();
 	@()--
-	C-lang uses "C" locale in default setting and all 8bit char is vaild. --
+	C-lang uses "C" locale in default and all 8bit char is vaild. --
 	(www.gnu.org/software/grep/manual/html_node/Character-Encoding.html) --
-	'  'eg) int main(){ puts(setlocale(LC_CTYPE, NULL)); } //>> "C" --
+	`   `eg) int main(){ puts(setlocale(LC_CTYPE, NULL)); } //>> "C" --
 	--
 	and regex semantics are differences from locale "C" to "UTF-8". --
-	'  'C : "[Σ]" == "[\316\243]" == "(\316|\243)" //binary \316 or \243 --
-	'  'u8: "[Σ]" == "\316\243" //binary sequence is 1 charactor --
+	`   `C : "[Σ]" == "[\316\243]" == "(\316|\243)" //binary \316 or \243 --
+	`   `u8: "[Σ]" == "\316\243" //binary sequence is 1 charactor --
 
 	@(list)
 	ureg_new(): use OS locale, setlocale(LC_CTYPE, "") (see ~$ echo $LANG) and
 	use its locale when search.
-	ureg_new_raw(): uses current locale and never changes locale setting, so
-	adjusting locale is user duty. if new/search locale isnt the same, you
-	may get the strange results. robj->lc saves setlocale(LC_TYPE,NULL) str.
+	ureg_new_raw(): uses current locale (maybe "C") and never changes locale,
+	so adjusting locale is user duty. if new/search locale isnt the	same,
+	you may get the strange results. robj->lc saves setlocale(LC_TYPE,NULL) str.
 	@()--
 	sample:
 	@(code)
@@ -226,10 +226,10 @@ title=ureg section=3 repnl=\040
 	//~$ cc src.c  libureg.a
 	@()--
 	malloc()/free() isnt executed every time. you can avoid the overhead.
-	but locale setting is very confusing so I reccomend you to use
+	but locale setting is very confusing so I recommend you to use
 	ureg_new() except rare/special usage.	--
 	--
-	'_param'
+	`_param`
 	@(list)
 	r   : regex str. mb class/range works only under the mb locale env.--
 		[Σ-Τ] == "(\u03a3|\u03a4)"  //"XXX.UTF-8"	--
@@ -237,18 +237,19 @@ title=ureg section=3 repnl=\040
 	[rlen]: r size. use strlen(r) if set -1/noset
 	[syn] : use ERE if -1/noset. ureg_ere_syn()/ureg_bre_syn() returns
 		ERE/BRE flag.	--
-		'  'int syn = ureg_bre_syn(); // or ureg_ere_syn(); --
-		'  'robj = ureg_new("a\\(b\\)c", -1, syn); --
-		'  'rc = ureg_search(robj, "00abc");	//hit rc=2	--
+		`   `int syn = ureg_bre_syn(); // or ureg_ere_syn(); --
+		`   `robj = ureg_new("a\\(b\\)c", -1, syn); --
+		`   `rc = ureg_search(robj, "00abc");	//hit rc=2	--
 	@()--
 	
-	'_return'
+	`_return`--
+	you may use only 'result buffer' in usual.
 	@(list)
 	robj->data : ptr to compiled regex data
-	robj->fastmap : ''char arr[255]. if r="[ab]c", arr['a'], ['b'] is 1. others is 0.''
+	robj->fastmap : char arr[255]. if r="[ab]c", arr['a'], ['b'] is 1. others is 0.
 	robj->lc : copy of setlocale(LC_CTYPE, NULL) str when regex compiled.
 	robj->rawflg : 0/1 == ureg_new()/ureg_new_raw()
-	others : result buffer
+	other members : result buffer.
     @()--
 
 	2. search
@@ -262,20 +263,21 @@ title=ureg section=3 repnl=\040
 	ureg_search_head(): check only BOS like lex scanner
 	@()--
 	
-	'_param'
+	`_param`
 	@(list)
-	robj : search result is set to this member. set NULL / -1 if nohit.
+	robj : search result is set to this member. member value will be set
+		NULL/-1 if nohit.
 	char* robj->p : full matching ptrpos
-	int obj->sz : byte size of matching str.
-	char* obj->pbk[10]: back reference ptrpos. obj->p == obj->pbk[0]
-	int obj->szbk[10]: byte size of back references. obj->sz==obj->szbk[0]. 
-		posix-ERE syntax doesnt allow backref \1-9, but to hold backref data
+	int robj->sz : byte size of matching str.
+	char* robj->pbk[10]: back reference ptrpos. robj->p == robj->pbk[0]
+	int robj->szbk[10]: byte size of back references. robj->sz==robj->szbk[0]. 
+		posix-ERE doesnt allow backref syntax \1-\9, but to hold backref data
 		is lawful. posix regcomp(), REG_NOSUB also holds its data.
 	s		: search target string ptr
 	[slen]	: use strlen(s) if -1/noset
 	@()
 
-	'_return'
+	`_return`
 	@(list)
 	int rc: funcs rtns >=0 or <0 == hit/nohit. srcptr+rc will be hittop ptr.
 	@()
@@ -289,17 +291,17 @@ title=ureg section=3 repnl=\040
 	rc = ureg_search_head(obj, s); //rc<0, nohit
 	rc = ureg_search_head(obj, s+3); //rc=0, hit "(ab)c", (s+3)[rc]='a'
 	@()--
-	search funcs doesnt support pirtial match. you need fulltext.
+	search funcs doesnt support partial match. you need fulltext.
 	@(code)
 	r = "a(bc)";
 	s = "123abc";
 	rc = ureg_search(obj, s, 4); //"123a", reg hits 'a' but fail. rc<0
-	// if supports rc= -5(pirtial/morestr) etc, you may use fgetc()
+	// if supports rc= -5(partial/morestr) etc, you may use fgetc()
 	@()--
 	back reference result \1-\9 is set to pbk/szbk[1-9]. [0] has fullmatch data.
 	index 1-9 applies to open parlen "(" order. the same as posix. --
-	'  'reg: ( a ( b | c ) ) --
-	'  'bk : \1  \2 --
+	`   `reg: ( a ( b | c ) ) --
+	`   `bk : \1  \2 --
 	--
 	back reference sample:
 	@(code)
@@ -334,14 +336,14 @@ title=ureg section=3 repnl=\040
 	ureg_iconv() doesnt treat regex. convert different encoding data.
 	posix iconv() api/manual is very awkward so make a wrapper. --
 	--
-	'_param'
+	`_param`
 		@(pre)
 	fenc  : from enc type str. "EBCDIC-BR" etc. see ~$ iconv -l
 	tenc  : to enc
 	&s    : srcptr-ref. this ag is changed by func, so pass the copy.
 	[slen]: src byte size. use strlen(*&s) if set -1/noset.
 		@()--
-	'_return'
+	`_return`
 	@(list)
 	p: suc/fail == notNULL/NULL. converted binary stream with bytesize.
 	use type punning (int), (char*) to get sz and binptr.
@@ -451,7 +453,7 @@ title=ureg section=3 repnl=\040
 	( http://web.mit.edu/gnu/doc/html/regex_2.html#SEC3 )--
 	--
 	important difference between BRE and ERE syntax is 
-	'backref', 'altername op |', 'anchor work' and 'repeat op':
+	`backref`, `alternate op |`, `anchor work` and `repeat op`:
 	@(code)@
 	         BRE	  ERE		eg
 	backref  \1-\9   nothing  B: \(a\)\1 >>aa,  E: (a)\1 >> undefined
@@ -460,7 +462,7 @@ title=ureg section=3 repnl=\040
 	repeat  context anywhare  B: *ab >> *ab     E: *ab >> undefined
 	@()--
 	I recommend you to use ERE in generally. you should use BRE only when
-	you need back-references or non-support ERE command (sed, grep etc)
+	you need back-references or non-support ERE command (sed, grep etc).
 	additionally, quote/esc the special charactors to avoid 'context depends'
 	regex.  eg) ERE: )abc >> [)]abc --
 	--
@@ -468,14 +470,14 @@ title=ureg section=3 repnl=\040
 	(https://swtch.com/~rsc/regexp/regexp1.html) --
 	--
 	--
-	''BRE doesnt have '|' op and  equivalent expression seems impossible'' --
-	'  'ERE: (ab|cd)* >> ( (ab){0,1} (cd){0,1} ){0,} --
-	'  'ERE: (ab|cd)+ >>  ??? --
+	BRE doesnt have '|' op and  equivalent expression seems impossible --
+	`   `ERE: (ab|cd)* >> ( (ab){0,1} (cd){0,1} ){0,} --
+	`   `ERE: (ab|cd)+ >>  ??? --
 	--
 	ERE doesnt have back-reference \1-\9. close expression is possible but
 	not perfect. catch  _ab_, __ab__, ___ab___ ... is: --
-	'  'BRE: \(_*\)[^_]\1	--
-	'  'ERE: (_[^_]*_) | (__[^_]*__) | (___[^_]*___) ...	--
+	`   `BRE: \(_*\)[^_]\1	--
+	`   `ERE: (_[^_]*_) | (__[^_]*__) | (___[^_]*___) ...	--
 	--
 	--
 	@(code)@
@@ -504,7 +506,7 @@ title=ureg section=3 repnl=\040
 	- support binary input
 	@()@
 @conforming_to posix-2001+
-@_ver 2021-08-08 v3.0.3
+@_ver 2021-11-25 v3.0.5
 @copyright Copyright 2021 momi-g, GPLv3+
 @_see
 @(code)@
@@ -584,18 +586,19 @@ void* ureg_iconv_impl(const char* fromenc, const char* toenc, char** str, int st
 /* tool macros */
 #ifndef ERRact
 #include <stdio.h>
-#include <errno.h>
-#include <unistd.h>
-#if  (200112L <= _POSIX_C_SOURCE +0)  /* nealy 200112L, _POSIX_C_SOURCE	c99*/
-#define ERRact(xpr, msg, act)	if(xpr){ fprintf(stderr, \
-	        "ERR: %s %d %s() pid:%d %s msg:%s sys:%s\n",__FILE__,__LINE__, __func__ \
-	        ,getpid(), "hit(" #xpr ")", msg, strerror(errno) );act ;}
-#else
-#define ERRact(xpr, msg, act)	if(xpr){ fprintf(stderr, \
-	        "ERR: %s %d %s() pid:%d %s msg:%s sys:%s\n",__FILE__,__LINE__, "func:c99+" \
-	        ,0 , "hit(" #xpr ")", msg, strerror(errno) );act ;}
-#endif
-#define STOP(xpr, msg)	ERRact(xpr, msg, fputs("STOP\n",stderr);exit(1))
+ #if (199901L <= __STDC_VERSION__ +0)	/* nealy 200112L, _POSIX_C_SOURCE	c99*/
+	#include <sys/types.h>
+	#include <unistd.h>
+	#define ERRactag	__func__, getpid()
+ #else
+	#define ERRactag	"func:c99+", 0
+ #endif
+ #include <string.h>
+ #include <errno.h>
+ #define ERRact(xpr, msg, act)	if(xpr){ int en_=errno; fprintf(stderr, \
+	"ERR: %s %d %s() pid:%d %s msg:%s sys:%s\n",__FILE__,__LINE__, ERRactag \
+	, "hit(" #xpr ")", msg, strerror(en_) ); act; }
+ #define STOP(xpr, msg)	ERRact(xpr, msg, fputs("STOP\n",stderr);exit(1) )
 #endif
 #define loop(a)		for(int lpcnt=1;lpcnt<=a;lpcnt++)
 
@@ -605,10 +608,14 @@ void* ureg_iconv_impl(const char* fromenc, const char* toenc, char** str, int st
 #include "hcut.h"
 #include "msgp.h"
 #include "laptime.h"
-#include "*SH_bn*.h"		//*SH_co* lib*SH_bn*.a	*/
+#include "*SH_bn*.h"		/*SH_co* lib*SH_bn*.a	*/
 #define loop(a)		for(int lpcnt=1;lpcnt<=a;lpcnt++)
 #define qu(...)		Qsub(__VA_ARGS__)
 #define Qsub(...)	#__VA_ARGS__
+
+#undef dbg
+#define dbg(...)
+
 #endif
 
 #ifdef TEST
@@ -730,7 +737,11 @@ HCUT_ADD(t_ureg_search) {
 	rc = ureg_search(obj, "1abいc");
 //printf("%.*s \n", obj->sz, obj->p);
 	eq_s(obj->p, "いc", "mbhit test");
-	eq_i(obj->sz, 3);
+
+	if( strrchr(obj->lc, '.') && strncasecmp( strrchr(obj->lc, '.')+1, "utf", 3)==0){
+		eq_i(obj->sz, 3);
+	}
+	
 	//dbg(rc, obj->p, obj->pbk[0], obj->sz, obj->szbk[0], setlocale(LC_CTYPE, NULL) );
 	ureg_free(obj);
 //
@@ -747,7 +758,11 @@ HCUT_ADD(t_ureg_search) {
 	rc = ureg_search(obj, s);
 	eq(obj->p!=NULL, "hit test");
 	eq_p(obj->p, s+4);
-	eq_i(obj->sz, 2);
+
+	if( strrchr(obj->lc, '.') && strncasecmp( strrchr(obj->lc, '.')+1, "utf", 3)==0){
+		eq_i(obj->sz, 2);
+	}
+
 	ureg_free(obj);
 //
 	rs = "[\377]";
@@ -765,10 +780,12 @@ HCUT_ADD(t_ureg_search) {
 	s="\377z";
 	obj = ureg_new(rs);
 	rc = ureg_search(obj, s);
+if( strrchr(obj->lc, '.') && strncasecmp( strrchr(obj->lc, '.')+1, "utf", 3)==0){
 	eq_i(rc, 1);
 	eq(obj->p!=NULL, "nohit test");
 	eq_p(obj->p, s+1);
 	eq_i(obj->sz, 1);
+}
 	ureg_free(obj);
 }
 #endif
@@ -794,6 +811,7 @@ HCUT_ADD(t_ureg_easy) {
 	const char* rs = "2";
 	const char* s = "123a\377あbc";
 	ureg_t res = ureg_easy(rs, s);
+	ureg_t* obj = &res;
 	eq_p(res.p, s+1);
 	eq_i(res.sz, 1);
 	
@@ -802,9 +820,19 @@ HCUT_ADD(t_ureg_easy) {
 	res = ureg_easy(rs, s);
 dbg(res.p, res.sz);
 	eq_p(res.p, s+7);
-	eq_i(res.sz, 2);
+
+if( strrchr(obj->lc, '.') && strncasecmp( strrchr(obj->lc, '.')+1, "utf", 3)==0){
+		eq_i(res.sz, 2);
+	}
 	
 	printf("%d %.*s \n", res.sz, res.sz, res.p);
+
+	rs="b\0.";
+	s = "ab\0xz";
+	res = ureg_easy(rs, s, 3, 6);
+dbg(res.p, res.sz);
+	eq_p(res.p, s+1);
+	eq_i(res.sz, 3);
 }
 #endif
 
@@ -854,12 +882,16 @@ HCUT_ADD(t_ureg_iconv) {
 	const char* ss = "\202\240\202\242\202\244";	//shift_jis
 	char* p = (char*)s;
 puts(p);
+fprintf(stderr, "hw %p, %s\n", p, s);
 	int* pp = ureg_iconv("UTF8", "SHIFT_JIS", &p, strlen(p));
+fprintf(stderr, "hw %p, %s\n", pp, s);
+if(pp){
 	int sz = pp[0];
 	char* str = (char*)&pp[1];
 dbg(sz);
 	puts(str);
 	eq_i(strcmp(ss, (char*)(pp+1) ), 0);
+}
 	free(pp);
 }
 #endif
@@ -875,10 +907,13 @@ HCUT_ADD(t_ureg) {
 	ureg_free(obj);
 //
 	obj = ureg_new("[あ]");
-	dbg(obj->p);
+	eq(obj!=NULL);
 	rc = ureg_search(obj, s="xあayz\343");
-	eq(obj->p -s == 1);
-	eq_i(obj->sz, 3);
+eq(obj->p -s == 1);
+if( strrchr(obj->lc, '.') && strncasecmp( strrchr(obj->lc, '.')+1, "utf", 3)==0){
+		eq_i(obj->sz, 3);
+	}
+
 	// dbg(obj);exit(1);
 	// dbg(rc, obj->sidx, obj->eidx);
 	ureg_free(obj);
@@ -887,7 +922,11 @@ HCUT_ADD(t_ureg) {
 	rc = ureg_search_head(obj, s="あxayz\343", -1);
 	eq(rc==0);
 	eq_p(obj->p, s);
-	eq_i(obj->sz, 3);
+//eq_i(obj->sz, 3);
+if( strrchr(obj->lc, '.') && strncasecmp( strrchr(obj->lc, '.')+1, "utf", 3)==0){
+		eq_i(obj->sz, 3);
+	}
+
 	rc = ureg_search_head(obj, s="xあayz\343");
 	eq(rc<0);
 	eq_p(obj->p, NULL);
@@ -917,10 +956,15 @@ HCUT_ADD(t_ureg) {
 	rc = ureg_search(obj, s="xあyz\343", -1);
 	eq(rc>0);
 	eq(obj->p -s == 1);
-	eq_i(obj->sz, 3);
+//eq_i(obj->sz, 3);
+if( strrchr(obj->lc, '.') && strncasecmp( strrchr(obj->lc, '.')+1, "utf", 3)==0){
+		eq_i(obj->sz, 3);
+	}
+
 	setlocale(LC_ALL, sv);
 	// dbg(rc, obj->sidx, obj->eidx);
 	ureg_free(obj);
+lb_RTN:;
 }
 #endif
 
@@ -1028,7 +1072,7 @@ laptime("strstr(): " qu(Lcnt));
 }
 #endif
 
-#ifdef TEST
+#ifdef TEST_
 #include "oniguruma.h"	//*SH_co*	libonig.a	*/
 HCUT_ADD(t_bm4) {
 	int rc=0;
@@ -1101,7 +1145,7 @@ int main(){
 //SH_SMPE*/
 
 #ifdef TEST
-HCUT_RUN("stderr", 1,	/* keep newline. use for SH sed edit, -t test.*/
+HCUT_RUN("stderr", 3,	/* keep newline. use for SH sed edit, -t test.*/
 //autofill by brp,	t_ureg_iconv, t_ureg, t_bm1, t_bm2, t_bm3
 );
 #endif
@@ -1109,6 +1153,21 @@ HCUT_RUN("stderr", 1,	/* keep newline. use for SH sed edit, -t test.*/
 /*
  change log
  --
+2022-09-25 Momi-g	<dmy@dmy.dmy>
+	
+	* *SH_bn*.c (tests): skip obj->sz tests if non-UTF8 env (strncasecmp)
+
+2021-11-25  Momi-g	<dmy@dmy.dmy>
+
+	* *SH_bn*.c (ver): v3.0.5
+	* *SH_bn*.c (TEST): add build test brpcode
+	* *SH_bn*.c (doc) : update doc
+
+2021-11-16  Momi-g	<dmy@dmy.dmy>
+
+	* *SH_bn*.c (ver): v3.0.4
+	* *SH_bn*.c (ureg_search_impl): fix 64bit builderr, sarr >>  (void*)sarr
+
 2021-08-08  Momi-g	<dmy@dmy.dmy>
 
 	* *SH_bn*.c (doc): fix doc, add amn script v3.0.3
@@ -1168,20 +1227,21 @@ HCUT_RUN("stderr", 1,	/* keep newline. use for SH sed edit, -t test.*/
 /*SH_EXT*/
 #ifndef ERRact
 #include <stdio.h>
-#include <errno.h>
-#include <unistd.h>
-#if  (200112L <= _POSIX_C_SOURCE +0)  /* nealy 200112L, _POSIX_C_SOURCE	c99*/
-#define ERRact(xpr, msg, act)	if(xpr){ fprintf(stderr, \
-	        "ERR: %s %d %s() pid:%d %s msg:%s sys:%s\n",__FILE__,__LINE__, __func__ \
-	        ,getpid(), "hit(" #xpr ")", msg, strerror(errno) );act ;}
-#else
-#define ERRact(xpr, msg, act)	if(xpr){ fprintf(stderr, \
-	        "ERR: %s %d %s() pid:%d %s msg:%s sys:%s\n",__FILE__,__LINE__, "func:c99+" \
-	        ,0 , "hit(" #xpr ")", msg, strerror(errno) );act ;}
+ #if (199901L <= __STDC_VERSION__ +0)	/* nealy 200112L, _POSIX_C_SOURCE	c99*/
+	#include <sys/types.h>
+	#include <unistd.h>
+	#define ERRactag	__func__, getpid()
+ #else
+	#define ERRactag	"func:c99+", 0
+ #endif
+ #include <string.h>
+ #include <errno.h>
+ #define ERRact(xpr, msg, act)	if(xpr){ int en_=errno; fprintf(stderr, \
+	"ERR: %s %d %s() pid:%d %s msg:%s sys:%s\n",__FILE__,__LINE__, ERRactag \
+	, "hit(" #xpr ")", msg, strerror(en_) ); act; }
+ #define STOP(xpr, msg)	ERRact(xpr, msg, fputs("STOP\n",stderr);exit(1) )
 #endif
-#define STOP(xpr, msg)	ERRact(xpr, msg, fputs("STOP\n",stderr);exit(1))
-#endif
-#define loop(a)		for(int lpcnt=1;lpcnt<=a;lpcnt++)
+#define loop(a)		for(int lpcnt=0;lpcnt<a;lpcnt++)
 
 typedef struct ureg_tag {
 	void* data;
@@ -1254,7 +1314,6 @@ void ureg_free(ureg_t* obj) {
 int ureg_ere_syn(void) { return ureg_erebin_syn_; }
 int ureg_bre_syn(void) { return ureg_brebin_syn_; }
 #include <locale.h>
-#include <regex.h>
 int ureg_search_impl(int headflg, ureg_t* obj, const char *str, int slen, ...);
 ureg_t* ureg_new_impl(int rawflg, const char* r, int rlen, int syn, ...) {
 	if(rlen== -1){ rlen=strlen(r); }
@@ -1335,9 +1394,10 @@ int ureg_search_impl(int headflg, ureg_t* obj, const char *str, int slen, ...) {
 //init
 	char* s = (char*)str;
 	if(slen<0){ slen=strlen(s); }
-	int sarr[10]=ARRI10;
-	int earr[10]=ARRI10;
-	struct re_registers bkres= {10, sarr, earr };	// 10... posix supports \1-\9
+	regoff_t sarr[10]=ARRI10;
+	regoff_t earr[10]=ARRI10;
+	//fix sarr >> (void*)sarr, 64bit builderr
+	struct re_registers bkres= {10, (void*)sarr, (void*)earr };	// 10... posix supports \1-\9
 	struct regex* sedobj = obj->data;
 	// use sed regexp.c, rtn suc/other=1/0. ag4:str offset=0, ag6:regoffsz=10
 	
@@ -1364,6 +1424,7 @@ int ureg_search_impl(int headflg, ureg_t* obj, const char *str, int slen, ...) {
 	// so s[range] == s[3] == 'X' is searched. s[2] is collect.
 
 	if(rc<0){ goto lb_ERR; }
+
 	for(int i=0;;i++) {
 		if(bkres.start[i] <0) {break;}
 		obj->pbk[i]  = s + bkres.start[i];	// set -1 if nomatch/err
@@ -1379,29 +1440,33 @@ lb_ERR:;
 }
 /*SH_ED*/
 
-/*SH_OP _ set -e;a=`sed -ne "/${C}DF/!d;:l;n;/${C}DE/q;p;bl"<$R0`;eval "$a"	#*/
-/*SH_OP	h $p"-t/s/b:test/smpl/bld /T:t+mem /f:functop	GPLv3+"	 #*/
-/*SH_OP	f sed -ne "/${C}DF/q;/;/d;/^[a-zA-Z].*)/p"<$R0 #*/
-
-/*SH_OP t $e"$CW";ftt "$@";$p'cc -O0 -Wall -pedantic -g -pg -ggdb3 $Rm `fOI $Rs $tf` `fg $Rs $tf` `fL`'|fv	#*/
+/*SH_OP _ set -e;a=`sed -ne "/${C}DF/!d;:l;n;/${C}DE/q;p;bl"<$R0`;eval "$a";set +e	#*/
+/*SH_OP	h $p"-tsbS:test/eg/.o/.so -LMP:leak,mem,prof -f:funcs -o:bldout		GPLv3+"	 #*/
+/*SH_OP	f sed -ne "/${C}DF/q;/;/d;/^[a-z].*)/p"<$R0 #*/
+/*SH_OP t $e"$CW";ftt "$@";$p'cc -O0 -static -Wall -pedantic -g -pg -ggdb3 $Rm `fOI $Rs $tf` `fg $Rs $tf` `fL`'|fv	#*/
 /*SH_OP T $e"$CW";ftt "$@";$p'cc -O3 $Rm `fOI $Rs $tf ` `fg $Rs $tf ` `fL`'|fv	#*/
-/*SH_OP s $e"$CW";fgr "${C}SMP" "${C}SMPE"<$Rs|fbn>eg.c;$p'cc eg.c `fg eg.c`'|fv #*/
-/*SH_OP L $p"valgrind --leak-check=full ./a.out 2>&1|sed -e '/SUMMA/!d;n;n;n;n'"|fv #*/
-/*SH_OP M $p"fM"|fv	 #*/
+/*SH_OP s $e"$CB";fgr0 "${C}SMP" "${C}SMPE"<$Rs|fbn>eg.c;$p'cc eg.c `fg eg.c` `fOI eg.c`'|fv #*/
+
+/*SH_OP L $p"valgrind --leak-check=full --show-leak-kinds=all --track-origins=yes --verbose ./a.out 2>&1|sed -e '/SUMMA/!d;n;n;n;n'"|fv #*/
+/*SH_OP M $p"fM ./a.out"|fv	 #*/
 /*SH_OP P $p'valgrind --tool=callgrind --callgrind-out-file=log.out ./a.out;kcachegrind log.out'|fv	 #*/
 
-/*SH_OP W $e"$Cm$O$Cw";$i0;$i1;fbn<$Rh>$Rm;mv $Rm $Rh;$p"$Rs $tf";$e"$CJ"	#*/
-/*SH_OP J fgr "${C}LS" "${C}ED"<$R0>tmp.c;fgr "${C}EXT" "${C}ED"<$R0|fbn>>tmp.c	#*/
+/*SH_OP b $e"$CW";$p'cc -c $Rs -pedantic -O2 -Wall -g `fg $Rs` `fI $Rs`'|fv;$p"$bn.o"	#*/
+/*SH_OP B $e"$Cb";$p"ar -r lib$bn.a $bn.o `fO $Rs`"|fv;$p"lib$bn.a"	#*/
+/*SH_OP A $e"$CB";$p'fA lib$bn.a `fg $Rh $Rs|fu|grep '[.]a$'|fU`'|fv;$p"lib$bn.a" #*/
+/*SH_OP S $e"$Cb";$p"cc -shared -fPIC -o lib$bn.so $bn.o `fOI $Rs` `fg $Rs`"|fv;$p"lib$bn.so" #*/
+/*SH_OP W $e"$Cm$O$Cw">/dev/null;fborn;$p"$Rs $Rh $tf";$e"$CJ"	#*/
+/*SH_OP J fgr "${C}LS" "${C}ED"<$R0>sedimpl.code;fgr "${C}EXT" "${C}ED"<$R0|fbn>>sedimpl.code	#*/
 
-/*SH_OP y $e"$CW";fy	#*/
-/*SH_OP Y $e"$Cy";fU $( ($p"lib$bn.a";fg $Rs $Rh)|$n|grep '[.]a$'|$U)	#*/
-/*SH_OP o $p'fman $R0 3'|fv		#*/
+/*SH_OP o $e"$CW";$p'fman $Rh 3'|fv		#*/
 
 /*SH_DF
 #-- noob
-fman()( fgr0 "${C}doc" "${C}docE"<$1|amn >$bn.$2
-mandoc -Thtml <$bn.$2 >${bn}_$2.html
-mandoc -Tps <$bn.$2 >${bn}_$2.pdf
+fman()( $p"fgr0 '${C}doc' '${C}docE'<$1|amn >$bn.$2
+ mandoc -Thtml <$bn.$2 >$bn.$2.html
+ #fgr0 '${C}doc' '${C}docE'<$1|amn -Dzwsp=1 >$Rm
+ man -Tutf8 /dev/stdin<$bn.$2|sed -e 's/.`printf \"\\b\"`//g'>$bn.$2.txt
+ "|fv
 )
 
 #-- local
@@ -1411,7 +1476,7 @@ bn=`basename ${Rs%.*}`; tf=${Rs%/*}/${bn}.ts.${Rs##*.}; e="eval "; p="$Rp"
 #-- mod
 fv()(while read -r a;do $e"cat<<E$O# $a${O}E"|sed -e 's@-L.*-L[^ ]*@-L(omit)@g'>/dev/stderr;$e"$a";done)
 
-fbn()(sed -e "s@\*${C##*]}bn\*@$bn@g"|frf)
+fbn()(sed -e "s@\*${C##*]}bn\*@$bn@g"|frf|frv|flit)
 fsn()(tr -s ' \t' '\n')
 fsl()(tr -s '\n' ' ')
 fu()(fsn|sort -u)
@@ -1423,16 +1488,16 @@ fgR()(sed -ne "/$1/bl;p;d;:l;n;/$2/d;bl")	#切すて
 fg()(sed -ne "s/.*${C##*]}co\*\([^*]*\).*$/\1/p" "$@"|fsn|awk '!a[$0]{a[$0]=1;print}'|fsl)
 
 # fO src.o from inc"src.abc" etc. kick self
-fO()(set -- `fdp "$@"|awk '$0~/[.](h|hpp)$/{print}'|sed -e 's/[.][^.]*$/.o/'|fU`
+fO()(set -- `fdp "$@"|awk '$0~/[.](h|hpp)$/{print}'|sed -e 's/[.][^.]*$/.c/'|fU`
 	buf="";for i;do test -f $i&&buf="$buf $i";done;$p"$buf"
 )
-fI()(fdp "$@"|sed -e 's/[^/]*$//g'|fu|sed -e '/./s/^/ -I/g'|fU)
+fI()(fdp "$@"|sed -e 's/[^/]*$//g'|fu|sed -e '/./s/^/ -I/g'|fu|grep -v '^\-I$'|fU)
 fL()(find -L `dirname $R0` -type d|sed -e 's/^/-L/g'|fU)
 # inc""系.h,hpp,oをパス付きで羅列 OIはfdpが重複するので高速化でまとめる 複数file_ok
 fOI()(
 set -- `fdp "$@"`
-s="-I./ "`$p"$@"|sed -e 's/[^/]*$//g'|fu|sed -e 's/^/ -I/g'|fU`
-set -- `$p"$@"|awk '$0~/[.](h|hpp)$/{print}'|sed -e 's/[.][^.]*$/.o/'|fU`
+s="-I./ "`$p"$@"|sed -e 's/[^/]*$//g'|fu|sed -e 's/^/ -I/g'|fu|grep -v '^\-I$'|fU`
+set -- `$p"$@"|awk '$0~/[.](h|hpp)$/{print}'|sed -e 's/[.][^.]*$/.c/'|fU`
 buf="";for i;do test -f $i&&buf="$buf $i";done;
 $p"$buf $s"
 )
@@ -1493,23 +1558,32 @@ EEE
 
 #-- longcmd
 frf()(
- awk -v r="${C##*]}rf" 'match($0,r){
- s=substr($0, RSTART+RLENGTH+1)
- gsub(/.[^*]*$/, "", s);split(s, a)
- m="[ -f %s ]&&echo \"/*--copyfrom %s*\"/&&cat %s&&echo \"/*--copyend %s*\"/"
- for(i=1;v=a[i];i++){ system( sprintf(m, v,v,v,v))}
+ # *sh_rf* 0 a.txt b.txt ...でcat纏めて出力 top0でsrcinfoは無し出力
+ awk -v tg="${C##*]}rf" 'index($0,tg){
+ s=substr($0, index($0,tg)+length(tg)+1);split(s, a)
+ m="[ -f \"%s\" ]&&(echo \"/*--copyfrom %s*\"/;cat \"%s\";echo \"/*--copyend %s*\"/)"
+ mm="[ -f \"%s\" ]&&(_=\"%s\"/;cat \"%s\";_=\"%s\")"
+ for(i=1;i in a;i++){v=a[i];if(v==0){m=mm;continue};system(sprintf(m,v,v,v,v)) }
  next
  }
  {print}'
 )
+frv()(buf=`awk '$1=="@_ver" {print $3;exit}'<$R0`;sed -e "s@\*${C##*]}ver\*@$buf@g")
+flit()(sed -ne "/${C}lit/bl;p;d;:l;n;/${C}litE/d;"'s/[\]/&&/g;s/"/\\"/g;s@.*@"&\\n"@g;p;bl')
 
-ftt()(a="`sed -ne 's@^HCUT_ADD(\([^)]*\).*@\1, @p' $tf|tr -d '\n'`NULL"
-	if [ $# != 0 ];then	a=""; for i;do a="$a $i,";done; a="$a NULL"; fi
-	sed -ne "p;/_RUN/bl;d;:l;/[)]/{c\\$O $a)$O p;d};n;bl"<$tf>$Rm;mv $Rm $tf
-	cat $Rs $tf>$Rm
-)
-i0=$e'fgr0 "^#ifdef TEST" "^#endif"<$R0|fbn>$tf'
-i1=$e'fgR "^#ifdef TEST" "^#endif"<$Rs|fbn>$Rm;mv $Rm $Rs;fbn<$Rh>$Rm;mv $Rm $Rh'
+fte(){
+ cat > $Rm-
+ a="`sed -ne 's@^HCUT_ADD(\([^)]*\).*@\1, @p' $Rm-|tr -d '\n'`NULL"
+ if [ $# != 0 ];then	a=""; for i;do a="$a $i,";done; a="$a NULL"; fi
+ sed -ne "p;/_RUN/bl;d;:l;/[)]/{c\\$O $a)$O p;d};n;bl" $Rm-
+ rm $Rm-
+}
+ftt()(fte "$@"<$tf>$Rm;mv $Rm $tf; cat $Rs $tf>$Rm)
+fborn(){
+ fgr0 "^#ifdef TEST" "^#endif"<$R0|fbn>$tf
+ fgR "^#ifdef TEST_" "^#endif"<$R0 |fgr0 "^#ifdef TEST" "^#endif"|fbn|fte>tests.code
+ fgR "^#ifdef TEST" "^#endif"<$Rs|fbn>$Rm;mv $Rm $Rs;fbn<$Rh>$Rm;mv $Rm $Rh
+}
 fM()(
  valgrind -q --tool=massif --massif-out-file=./vmem.buf --stacks=yes --trace-children=yes $1>/dev/null
  ms_print ./vmem.buf|sed -ne '/[KMG]B/bl;d;:l;/snap/q;p;n;bl';rm ./vmem.buf)
