@@ -644,6 +644,10 @@ int main(){
 /*
  change log
  --
+2022-09-25 Momi-g	<dmy@dmy.dmy>
+	
+	* ureg.c (tests): skip obj->sz tests if non-UTF8 env (strncasecmp)
+
 2021-11-25  Momi-g	<dmy@dmy.dmy>
 
 	* ureg.c (ver): v3.0.5
