@@ -20,7 +20,7 @@
 title=ureg section=3 repnl=\040
 @name	ureg
 @_brief	portable BRE/ERE regex api
-@synopsis
+@_syno
  #include "ureg.h"
  
  //main func 
@@ -53,7 +53,6 @@ title=ureg section=3 repnl=\040
 @tl;dr
 	@(code)@
 	#include "ureg.h"
-	
 	int main() {
 		  ureg_t res = ureg_easy("a[bc]", "123abc");	//dfl:ERE
 		  printf("%.*s \n", res.sz, res.p);	// == "ab"
@@ -75,7 +74,7 @@ title=ureg section=3 repnl=\040
 	printf("%.*s", res.szbk[0], res.pbk[0]);	//>> "ab"
 	
 	//complex
-	ureg_t* obj = ureg_new("a(b|c)");	//rtn NULL: err
+	ureg_t* obj = ureg_new("a(b|c)");	//rtn NULL if err
 	const char* s = "123abc";
 	int rc = ureg_search(obj, s);	//rc== hit:>=0 nohit/err:<0
 	  //rc=3, obj->p=s+3(rc), obj->sz=2 
@@ -93,6 +92,7 @@ title=ureg section=3 repnl=\040
 	setlocale(LC_CTYPE, "C");	// reset
 	rc = ureg_search(obj, s);
 	ureg_free(obj);
+	//--regex end
 	
 	//ureg_iconv(): not regex. conv encode UTF-8, EBCDIC etc
 	const char* s0 = "hwd";  //"hwd"=="\150\167\144" in C charset
@@ -111,7 +111,7 @@ title=ureg section=3 repnl=\040
   //~$ cc src.c libureg.a
 	@()@
 
-@description
+@_desc
 	ureg uses posix-ERE with the following expantion in default.
 	some items are compromised for reasons --
 	@(pre)@
@@ -126,25 +126,25 @@ title=ureg section=3 repnl=\040
     --
 
 	@(raw).SS easy mode@()--
-	'	'ureg_t ureg_easy(r, s [, rlen, slen, syn]); --
+	`	`ureg_t res = ureg_easy(r, s [, rlen, slen, syn]); --
 	--
 	ureg_easy() uses for oneshot search. use '-1' if rlen/slen/syn isnt set.
 	search result is set to rtn. if nohit, set res.p==NULL, res.sz<0. --
-	'  'res = ureg_easy("a[bc]", "123abc");  //hit, res.p="..."+3, res.sz=2 --
-	'  'res = ureg_easy("a[bc]", "123abc", -1,-1,-1);  //same --
+	`	`res = ureg_easy("a[bc]", "123abc");  //hit, res.p="..."+3, res.sz=2 --
+	`	`res = ureg_easy("a[bc]", "123abc", -1,-1,-1);  //same --
 	--
-	'_param'
+	`_param`
 	@(pre)
 	r     : regex str
 	s     : search target string/binary
 	[rlen]: r size. use strlen(r) if set -1/noset
 	[slen]: s size
-	[syn] : change regex syntax. see below 'complex mode'
+	[syn] : change regex syntax. see below 'complex mode'. (dfl:ERE)
 	@()--
 
-	'_return'
+	`_return`
 	@(pre)
-    res.p : matched ptr. res.p[0]==@'a@' in above sample. "123(a)bc"
+    res.p : matched ptr. res.p[0]=='a' in above sample. "123(a)bc"
     res.sz: match string byte size
     others: see below (complex mode)
     @()--
@@ -157,12 +157,12 @@ title=ureg section=3 repnl=\040
 	sample:
 		@(pre)
 	#include "ureg.h"
-	int main(int argc, char** argv){
+	int main(){
 		ureg_t res = ureg_easy("a[bc]", "123abc");
-		printf("%.*s \n" res.sz, res.p);	//>> disp "ab"
+		printf("%.*s \n", res.sz, res.p);	//>> disp "ab"
 		return 0;	//no memleak
 	}
-	// ~$ gcc src.c libureg.a
+	// ~$ cc src.c libureg.a
 		@()--
 	@(raw).SS complex mode@()--
 	divided to 3 parts, compile >> search >> free	--
@@ -174,20 +174,20 @@ title=ureg section=3 repnl=\040
 	int syn = ureg_ere_syn();
 	int syn = ureg_bre_syn();
 	@()--
-	C-lang uses "C" locale in default setting and all 8bit char is vaild. --
+	C-lang uses "C" locale in default and all 8bit char is vaild. --
 	(www.gnu.org/software/grep/manual/html_node/Character-Encoding.html) --
-	'  'eg) int main(){ puts(setlocale(LC_CTYPE, NULL)); } //>> "C" --
+	`   `eg) int main(){ puts(setlocale(LC_CTYPE, NULL)); } //>> "C" --
 	--
 	and regex semantics are differences from locale "C" to "UTF-8". --
-	'  'C : "[Σ]" == "[\316\243]" == "(\316|\243)" //binary \316 or \243 --
-	'  'u8: "[Σ]" == "\316\243" //binary sequence is 1 charactor --
+	`   `C : "[Σ]" == "[\316\243]" == "(\316|\243)" //binary \316 or \243 --
+	`   `u8: "[Σ]" == "\316\243" //binary sequence is 1 charactor --
 
 	@(list)
 	ureg_new(): use OS locale, setlocale(LC_CTYPE, "") (see ~$ echo $LANG) and
 	use its locale when search.
-	ureg_new_raw(): uses current locale and never changes locale setting, so
-	adjusting locale is user duty. if new/search locale isnt the same, you
-	may get the strange results. robj->lc saves setlocale(LC_TYPE,NULL) str.
+	ureg_new_raw(): uses current locale (maybe "C") and never changes locale,
+	so adjusting locale is user duty. if new/search locale isnt the	same,
+	you may get the strange results. robj->lc saves setlocale(LC_TYPE,NULL) str.
 	@()--
 	sample:
 	@(code)
@@ -214,10 +214,10 @@ title=ureg section=3 repnl=\040
 	//~$ cc src.c  libureg.a
 	@()--
 	malloc()/free() isnt executed every time. you can avoid the overhead.
-	but locale setting is very confusing so I reccomend you to use
+	but locale setting is very confusing so I recommend you to use
 	ureg_new() except rare/special usage.	--
 	--
-	'_param'
+	`_param`
 	@(list)
 	r   : regex str. mb class/range works only under the mb locale env.--
 		[Σ-Τ] == "(\u03a3|\u03a4)"  //"XXX.UTF-8"	--
@@ -225,18 +225,19 @@ title=ureg section=3 repnl=\040
 	[rlen]: r size. use strlen(r) if set -1/noset
 	[syn] : use ERE if -1/noset. ureg_ere_syn()/ureg_bre_syn() returns
 		ERE/BRE flag.	--
-		'  'int syn = ureg_bre_syn(); // or ureg_ere_syn(); --
-		'  'robj = ureg_new("a\\(b\\)c", -1, syn); --
-		'  'rc = ureg_search(robj, "00abc");	//hit rc=2	--
+		`   `int syn = ureg_bre_syn(); // or ureg_ere_syn(); --
+		`   `robj = ureg_new("a\\(b\\)c", -1, syn); --
+		`   `rc = ureg_search(robj, "00abc");	//hit rc=2	--
 	@()--
 	
-	'_return'
+	`_return`--
+	you may use only 'result buffer' in usual.
 	@(list)
 	robj->data : ptr to compiled regex data
-	robj->fastmap : ''char arr[255]. if r="[ab]c", arr['a'], ['b'] is 1. others is 0.''
+	robj->fastmap : char arr[255]. if r="[ab]c", arr['a'], ['b'] is 1. others is 0.
 	robj->lc : copy of setlocale(LC_CTYPE, NULL) str when regex compiled.
 	robj->rawflg : 0/1 == ureg_new()/ureg_new_raw()
-	others : result buffer
+	other members : result buffer.
     @()--
 
 	2. search
@@ -250,20 +251,21 @@ title=ureg section=3 repnl=\040
 	ureg_search_head(): check only BOS like lex scanner
 	@()--
 	
-	'_param'
+	`_param`
 	@(list)
-	robj : search result is set to this member. set NULL / -1 if nohit.
+	robj : search result is set to this member. member value will be set
+		NULL/-1 if nohit.
 	char* robj->p : full matching ptrpos
-	int obj->sz : byte size of matching str.
-	char* obj->pbk[10]: back reference ptrpos. obj->p == obj->pbk[0]
-	int obj->szbk[10]: byte size of back references. obj->sz==obj->szbk[0]. 
-		posix-ERE syntax doesnt allow backref \1-9, but to hold backref data
+	int robj->sz : byte size of matching str.
+	char* robj->pbk[10]: back reference ptrpos. robj->p == robj->pbk[0]
+	int robj->szbk[10]: byte size of back references. robj->sz==robj->szbk[0]. 
+		posix-ERE doesnt allow backref syntax \1-\9, but to hold backref data
 		is lawful. posix regcomp(), REG_NOSUB also holds its data.
 	s		: search target string ptr
 	[slen]	: use strlen(s) if -1/noset
 	@()
 
-	'_return'
+	`_return`
 	@(list)
 	int rc: funcs rtns >=0 or <0 == hit/nohit. srcptr+rc will be hittop ptr.
 	@()
@@ -277,17 +279,17 @@ title=ureg section=3 repnl=\040
 	rc = ureg_search_head(obj, s); //rc<0, nohit
 	rc = ureg_search_head(obj, s+3); //rc=0, hit "(ab)c", (s+3)[rc]='a'
 	@()--
-	search funcs doesnt support pirtial match. you need fulltext.
+	search funcs doesnt support partial match. you need fulltext.
 	@(code)
 	r = "a(bc)";
 	s = "123abc";
 	rc = ureg_search(obj, s, 4); //"123a", reg hits 'a' but fail. rc<0
-	// if supports rc= -5(pirtial/morestr) etc, you may use fgetc()
+	// if supports rc= -5(partial/morestr) etc, you may use fgetc()
 	@()--
 	back reference result \1-\9 is set to pbk/szbk[1-9]. [0] has fullmatch data.
 	index 1-9 applies to open parlen "(" order. the same as posix. --
-	'  'reg: ( a ( b | c ) ) --
-	'  'bk : \1  \2 --
+	`   `reg: ( a ( b | c ) ) --
+	`   `bk : \1  \2 --
 	--
 	back reference sample:
 	@(code)
@@ -322,14 +324,14 @@ title=ureg section=3 repnl=\040
 	ureg_iconv() doesnt treat regex. convert different encoding data.
 	posix iconv() api/manual is very awkward so make a wrapper. --
 	--
-	'_param'
+	`_param`
 		@(pre)
 	fenc  : from enc type str. "EBCDIC-BR" etc. see ~$ iconv -l
 	tenc  : to enc
 	&s    : srcptr-ref. this ag is changed by func, so pass the copy.
 	[slen]: src byte size. use strlen(*&s) if set -1/noset.
 		@()--
-	'_return'
+	`_return`
 	@(list)
 	p: suc/fail == notNULL/NULL. converted binary stream with bytesize.
 	use type punning (int), (char*) to get sz and binptr.
@@ -439,7 +441,7 @@ title=ureg section=3 repnl=\040
 	( http://web.mit.edu/gnu/doc/html/regex_2.html#SEC3 )--
 	--
 	important difference between BRE and ERE syntax is 
-	'backref', 'altername op |', 'anchor work' and 'repeat op':
+	`backref`, `alternate op |`, `anchor work` and `repeat op`:
 	@(code)@
 	         BRE	  ERE		eg
 	backref  \1-\9   nothing  B: \(a\)\1 >>aa,  E: (a)\1 >> undefined
@@ -448,7 +450,7 @@ title=ureg section=3 repnl=\040
 	repeat  context anywhare  B: *ab >> *ab     E: *ab >> undefined
 	@()--
 	I recommend you to use ERE in generally. you should use BRE only when
-	you need back-references or non-support ERE command (sed, grep etc)
+	you need back-references or non-support ERE command (sed, grep etc).
 	additionally, quote/esc the special charactors to avoid 'context depends'
 	regex.  eg) ERE: )abc >> [)]abc --
 	--
@@ -456,14 +458,14 @@ title=ureg section=3 repnl=\040
 	(https://swtch.com/~rsc/regexp/regexp1.html) --
 	--
 	--
-	''BRE doesnt have '|' op and  equivalent expression seems impossible'' --
-	'  'ERE: (ab|cd)* >> ( (ab){0,1} (cd){0,1} ){0,} --
-	'  'ERE: (ab|cd)+ >>  ??? --
+	BRE doesnt have '|' op and  equivalent expression seems impossible --
+	`   `ERE: (ab|cd)* >> ( (ab){0,1} (cd){0,1} ){0,} --
+	`   `ERE: (ab|cd)+ >>  ??? --
 	--
 	ERE doesnt have back-reference \1-\9. close expression is possible but
 	not perfect. catch  _ab_, __ab__, ___ab___ ... is: --
-	'  'BRE: \(_*\)[^_]\1	--
-	'  'ERE: (_[^_]*_) | (__[^_]*__) | (___[^_]*___) ...	--
+	`   `BRE: \(_*\)[^_]\1	--
+	`   `ERE: (_[^_]*_) | (__[^_]*__) | (___[^_]*___) ...	--
 	--
 	--
 	@(code)@
@@ -492,7 +494,7 @@ title=ureg section=3 repnl=\040
 	- support binary input
 	@()@
 @conforming_to posix-2001+
-@_ver 2021-08-08 v3.0.3
+@_ver 2021-11-25 v3.0.5
 @copyright Copyright 2021 momi-g, GPLv3+
 @_see
 @(code)@
